import { __decorate } from "tslib";
import '@finastra/icon';
import { html, LitElement } from 'lit';
import { property } from 'lit/decorators.js';
import { styles } from './base-styles.css';
export class BaseButton extends LitElement {
    constructor() {
        super(...arguments);
        /**
         * The label displayed inside the button
         */
        this.label = 'Button';
        /**
         * The name of the icon displayed before the label
         * Use trailingIcon to true to display this icon after the label
         */
        this.icon = '';
        /**
         * Use the smaller button size
         */
        this.dense = false;
        /**
         * Use the larger button size
         */
        this.large = false;
        /**
         * Is the button disabled or not
         */
        this.disabled = false;
        /**
         * Use the full width of its parent
         */
        this.fullwidth = false;
        /**
         * Display the icon after the label instead of before
         */
        this.trailingIcon = false;
        this.type = 'button';
    }
    render() {
        return html `<button aria-label="${this.label || this.icon}" ?disabled="${this.disabled}">
      ${this.icon && !this.trailingIcon ? this.renderIcon() : ''} <span class="fds-button__label">${this.label}</span>
      <slot></slot>
      ${this.icon && this.trailingIcon ? this.renderIcon() : ''}
    </button>`;
    }
    renderIcon() {
        return html ` <fds-icon> ${this.icon} </fds-icon>`;
    }
}
BaseButton.styles = [styles];
__decorate([
    property({ type: String })
], BaseButton.prototype, "label", void 0);
__decorate([
    property({ type: String })
], BaseButton.prototype, "icon", void 0);
__decorate([
    property({ type: Boolean })
], BaseButton.prototype, "dense", void 0);
__decorate([
    property({ type: Boolean })
], BaseButton.prototype, "large", void 0);
__decorate([
    property({ type: Boolean })
], BaseButton.prototype, "disabled", void 0);
__decorate([
    property({ type: Boolean })
], BaseButton.prototype, "fullwidth", void 0);
__decorate([
    property({ type: Boolean })
], BaseButton.prototype, "trailingIcon", void 0);
__decorate([
    property({ type: String })
], BaseButton.prototype, "type", void 0);
//# sourceMappingURL=base-button.js.map